@@ -1,7 +1,6 @@
-from keras_bert.backend import keras
-from keras_bert.backend import backend as K
+from tensorflow import keras
+from tensorflow.keras import backend as K
 from keras_pos_embd import PositionEmbedding
-from keras_layer_normalization import LayerNormalization
 
 
 class TokenEmbedding(keras.layers.Embedding):
