@@ -1,6 +1,8 @@
 from unittest import TestCase
+
 import numpy as np
-from keras_bert.backend import keras
+from tensorflow import keras
+
 from keras_bert.layers import MaskedConv1D, MaskedGlobalMaxPool1D
 
 
