@@ -1,6 +1,8 @@
 import unittest
+
 import numpy as np
-from keras_bert.backend import keras
+from tensorflow import keras
+
 from keras_bert.layers import Extract
 
 
