@@ -1,9 +1,9 @@
 import unittest
 
 import numpy as np
+from tensorflow import keras
+from tensorflow.keras import backend as K
 
-from keras_bert.backend import keras
-from keras_bert.backend import backend as K
 from keras_bert.layers import TaskEmbedding
 
 
